PokeNdArray

Struct PokeNdArray 

pub struct PokeNdArray<'mem, 'facet> { /* private fields */ }
Lets you mutate an n-dimensional array (implements mutable facet_core::NdArrayVTable proxies)

Implementations

Source

impl<'mem, 'facet> PokeNdArray<'mem, 'facet>

pub const unsafe fn new(value: Poke<'mem, 'facet>, def: NdArrayDef) -> Self

Creates a new poke ndarray.

Safety

The caller must ensure that def contains valid vtable function pointers that correctly implement the ndarray operations for the actual type, and that the element type matches def.t().

pub fn count(&self) -> usize

Get the total number of elements in the array.

pub fn n_dim(&self) -> usize

Get the number of dimensions.

pub fn dim(&self, i: usize) -> Option<usize>

Get the i-th dimension.

pub fn get(&self, index: usize) -> Option<Peek<'_, 'facet>>

Get a read-only view of the item at the given flat index.

pub fn get_mut(&mut self, index: usize) -> Option<Poke<'_, 'facet>>

Get a mutable view of the item at the given flat index.

Returns None if the underlying ndarray doesn’t provide mutable access or if the index is out of bounds.

pub fn as_mut_ptr(&mut self) -> Result<PtrMut, StrideError>

Get a mutable pointer to the start of the data buffer (if the array is strided).

pub fn byte_stride(&self, i: usize) -> Result<Option<isize>, StrideError>

Get the i-th stride in bytes.

pub const fn def(&self) -> NdArrayDef

Def getter.

pub const fn into_inner(self) -> Poke<'mem, 'facet>

Converts this PokeNdArray back into a Poke.

pub fn as_peek_ndarray(&self) -> PeekNdArray<'_, 'facet>

Returns a read-only PeekNdArray view.